@@ -6,7 +6,7 @@ use JSON;
 use REST::Client;
 use MIME::Base64;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub new {
     my ($class, $args) = @_;
@@ -32,12 +32,6 @@ sub new {
     return $self;
 }
 
-sub POST {
-    my ($self, $path, $headers, $payload) = @_;
-    $self->{client}->POST($path, encode_json($payload), { 'Content-Type' => 'application/json', %$headers });
-    return decode_json($self->{client}->responseContent());
-}
-
 sub GET {
     my ($self, $path) = @_;
     $self->{client}->GET($path);
@@ -79,29 +73,6 @@ sub _search {
     $self->{search}->{total} = $result->{total};
 }
 
-sub attach_files {
-    my ($self, $issue_key, @files) = @_;
-    foreach my $file (@files) {
-        open my $fh, '<', $file or die "Cannot open file $file: $!";
-        binmode $fh;
-        my $content = do { local $/; <$fh> };
-        close $fh;
-        
-        my $filename = $file;
-        $filename =~ s{.*/}{};
-
-        $self->{client}->POST(
-            "/rest/api/2/issue/$issue_key/attachments",
-            $content,
-            {
-                'X-Atlassian-Token' => 'no-check',
-                'Content-Type' => 'multipart/form-data',
-                'Content-Disposition' => "form-data; name=\"file\"; filename=\"$filename\"",
-            }
-        );
-    }
-}
-
 1;
 
 __END__
@@ -120,18 +91,8 @@ JIRA::REST::Lite - A lightweight Perl module for interacting with JIRA REST API
       password => 'mypass',
   });
 
-  # File a bug
-  my $issue = $jira->POST('/issue', undef, {
-      fields => {
-          project   => { key => 'PRJ' },
-          issuetype => { name => 'Bug' },
-          summary   => 'Cannot login',
-          description => 'Bla bla bla',
-      },
-  });
-
   # Get issue
-  $issue = $jira->GET("/issue/TST-101");
+  my $issue = $jira->GET("/issue/TST-101");
 
   # Iterate on issues
   $jira->set_search_iterator({
@@ -144,9 +105,6 @@ JIRA::REST::Lite - A lightweight Perl module for interacting with JIRA REST API
       print "Found issue $issue->{key}\n";
   }
 
-  # Attach files
-  $jira->attach_files('TST-123', '/path/to/doc.txt', 'image.png');
-
 =head1 DESCRIPTION
 
 JIRA::REST::Lite provides a simple interface for interacting with the JIRA REST API, with minimal dependencies.
@@ -159,12 +117,6 @@ JIRA::REST::Lite provides a simple interface for interacting with the JIRA REST
 
 Creates a new JIRA::REST::Lite object. The arguments can include C<url>, C<username>, C<password>, C<session>, C<pat>, and C<anonymous>.
 
-=head2 POST
-
-  my $issue = $jira->POST($path, \%headers, \%payload);
-
-Performs a POST request to the JIRA API.
-
 =head2 GET
 
   my $issue = $jira->GET($path);
@@ -185,12 +137,6 @@ Sets up an iterator for searching JIRA issues.
 
 Fetches the next issue from the search iterator.
 
-=head2 attach_files
-
-  $jira->attach_files($issue_key, @files);
-
-Attaches files to a JIRA issue.
-
 =head1 AUTHOR
 
 [Kawamura Shingo] <pannakoota@gmail.com>
